powered by
Resource path /activities/calories
get_calories(start_date, end_date)
A tibble with two columns: date and calories
date
calories
The start date of records to be returned in "yyyy-mm-dd" or date(time) format
The end date of records to be returned in "yyyy-mm-dd" or date(time) format
if (FALSE) { start_date <- lubridate::today() - lubridate::weeks(1) end_date <- lubridate::today() calories(date) }
Run the code above in your browser using DataLab