A tibble of the date, the heart rate zone (zone), the minimum heart rate in that zone (min_hr), the maximum heart rate in that zone (max_hr), the minutes in that zone (minutes_in_zone), and the calories burned in that zone (calories_out)
Arguments
start_date
The start date of records to be returned in "yyyy-mm-dd" or date(time) format
end_date
The end date of records to be returned in "yyyy-mm-dd" or date(time) format